﻿using System;
using System.Numerics;
using Dalamud.Interface.Windowing;
using ImGuiNET;

namespace DalamudShock.Windows
{
    public class ConfigWindow : Window, IDisposable
    {
        private Configuration Configuration;
        public ConfigWindow(Plugin plugin) : base("DalamudShock Config###With a constant ID")
        {
            Flags = ImGuiWindowFlags.NoScrollWithMouse;
            Size = new Vector2(600, 400); 
            SizeCondition = ImGuiCond.Always;
            Configuration = plugin.Configuration;
        }

        public void Dispose() { }

        public override void PreDraw()
        {
            if (Configuration.IsConfigWindowMovable)
            {
                Flags &= ~ImGuiWindowFlags.NoMove;
            }
            else
            {
                Flags |= ImGuiWindowFlags.NoMove;
            }
        }

        public override void Draw()
        {
            var apiKey = Configuration.openshockApiKey;
            if (ImGui.InputText("API Key", ref apiKey, 100))
            {
                Configuration.openshockApiKey = apiKey;
            }

            var shockerID = Configuration.OpenshockShockerID;
            if (ImGui.InputText("Shocker ID or Share Code", ref shockerID, 100))
            {
                Configuration.OpenshockShockerID = shockerID;
            }
            var maxShock = Configuration.MaxValue;
            if (ImGui.SliderInt("Intensity cap", ref maxShock, 0, 100))
            {
                Configuration.MaxValue = maxShock;
            }
            var maxLength = Configuration.MaxDuration;
            if (ImGui.SliderInt("Duration Cap (sec)", ref maxLength, 1, 30)) 
            {
                // Map the value from [1, 30] to [1000, 30000]
                Configuration.MaxDuration = maxLength;
            }
            bool isVibrationAllowed = Configuration.IsVibrationAllowed;
            if (ImGui.Checkbox("Allow Vibration", ref isVibrationAllowed)) 
            {
                Configuration.IsVibrationAllowed = isVibrationAllowed;
            }
            ImGui.SameLine();
            bool usePsc = Configuration.UsePishock;
            if (ImGui.Checkbox("Use PiShock API", ref usePsc))
            {
                Configuration.UsePishock = usePsc;
                Configuration.IsVibrationAllowed = usePsc;
            }
            ImGui.Spacing();
            if (usePsc)
            {
                string pishockUsername = Configuration.PiShockUser; 
                ImGui.InputText("PiShock Username", ref pishockUsername, 100); 
                Configuration.PiShockUser = pishockUsername;
            }
            ImGui.Spacing();
            bool instantZap = Configuration.ZapOnDamage;
            if (ImGui.Checkbox("Allow Vibration", ref instantZap)) 
            {
                Configuration.ZapOnDamage = instantZap;
            }
            ImGui.Spacing();
            if (ImGui.Button("Save Configuration"))
            {
                Configuration.Save();
            }
        }
    }
}
