﻿using System;
using System.Numerics;
using System.Net.Http;
using Dalamud.Interface.Windowing;
using ImGuiNET;
using Newtonsoft.Json;

namespace DalamudShock.Windows
{
    public class MainWindow : Window, IDisposable
    {
        private Plugin Plugin;
        private string openShockVersion = "Fetching...";

        public MainWindow(Plugin plugin)
            : base("This window has no reason to exist##69420",
                   ImGuiWindowFlags.NoScrollbar | ImGuiWindowFlags.NoScrollWithMouse)
        {
            SizeConstraints = new WindowSizeConstraints
            {
                MinimumSize = new Vector2(375, 330),
                MaximumSize = new Vector2(float.MaxValue, float.MaxValue)
            };

            Plugin = plugin;
            FetchOpenShockVersion();
        }

        public void Dispose() { }

        public override void Draw()
        {
            if (ImGui.Button("Show Settings"))
            {
                Plugin.ToggleConfigUI();
            }

            ImGui.Spacing();
            ImGui.Text("We aren't beating the bottom allegations with this one");

            // Display the OpenShock version
            ImGui.Spacing();
            ImGui.Text($"OpenShock Version: #{openShockVersion}");

        }

        private async void FetchOpenShockVersion()
        {
            try
            {
                using var client = new HttpClient();
                client.DefaultRequestHeaders.Add("OpenShockToken", Plugin.Configuration.openshockApiKey);
                client.DefaultRequestHeaders.Add("User-Agent",
                                                 "Dalamud/0.2 (Windows; U; Windows NT 10.4; x64) AppleWebKit/602.39 (KHTML, like Gecko)");

                var response = await client.GetAsync("https://api.shocklink.net/1");
                if (response.IsSuccessStatusCode)
                {
                    var responseData = await response.Content.ReadAsStringAsync();
                    var version = JsonConvert.DeserializeObject<dynamic>(responseData)?.data?.commit;
                    openShockVersion = version?.ToString().Substring(0, 7) ?? "Unknown";
                }
                else
                {
                    openShockVersion = "Error fetching version";
                }
            }
            catch (Exception ex)
            {
                openShockVersion = $"Error: {ex.Message}";
            }
        }
    }
}
